#
# spec file for package python-tablib
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%if 0%{?rhel}
# I get syntax errors in the brp-python-bytecompile step...
%define _python_bytecompile_errors_terminate_build 0
%endif
Name:           python-tablib
Version:        0.13.0
Release:        lp151.1.1
Summary:        Format agnostic tabular data library (XLS, JSON, YAML, CSV)
License:        MIT
Group:          Development/Languages/Python
URL:            http://python-tablib.org
Source:         https://files.pythonhosted.org/packages/source/t/tablib/tablib-%{version}.tar.gz
BuildRequires:  %{python_module PyYAML >= 3.12}
BuildRequires:  %{python_module odfpy >= 1.3.5}
BuildRequires:  %{python_module openpyxl >= 2.4.8}
BuildRequires:  %{python_module pandas >= 0.20.3}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module unicodecsv >= 0.14.1}
BuildRequires:  %{python_module xlrd >= 1.1.0}
BuildRequires:  %{python_module xlwt >= 1.3.0}
BuildRequires:  %{python_module xml}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  python2-backports.csv
Requires:       python-PyYAML >= 3.12
Requires:       python-odfpy >= 1.3.5
Requires:       python-openpyxl >= 2.4.8
Requires:       python-unicodecsv >= 0.14.1
Requires:       python-xlrd >= 1.1.0
Requires:       python-xlwt >= 1.3.0
Requires:       python-xml
Suggests:       python-pandas >= 0.20.3
BuildArch:      noarch
%ifpython2
Requires:       python2-backports.csv
%endif
%python_subpackages

%description
Tablib is a format-agnostic tabular dataset library, written in Python.

Output formats supported:

- Excel (Sets + Books)
- JSON (Sets + Books)
- YAML (Sets + Books)
- HTML (Sets)
- TSV (Sets)
- CSV (Sets)

%prep
%setup -q -n tablib-%{version}
# Remove shebang lines from non-executable scripts:
find tablib -name "*.py" | xargs sed -i '1 { /^#!/ d }'

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%python_exec test_tablib.py

%files %{python_files}
%license LICENSE
%doc README.rst HISTORY.rst
%{python_sitelib}/*

%changelog
* Tue Mar 26 2019 pgajdos@suse.com
- version update to 0.13.0
  * no upstream changelog (HISTORY.rst outdated), see git log
- deleted patches
  - openpyxl-usage-fix.patch (upstreamed)
* Thu Mar  7 2019 John Vandenberg <jayvdb@gmail.com>
- Add openpyxl-usage-fix.patch to workaround incompatibility with
  current releases of openpyxl
- Add HISTORY.rst to %%doc
- Add minimum versions of dependencies from upstream
- Use %%license
- Update to v0.12.1
  - Add Pandas DataFrame support
* Thu Aug 24 2017 tbechtold@suse.com
- update to 0.11.5:
  - Use ``yaml.safe_load`` for importing yaml.
  - Use built-in `json` package if available
  - Support Python 3.5+ in classifiers
  - Fixed textual representation for Dataset with no headers
  - Handle decimal types
  - Release fix.
  - Fix export only formats.
  - Fix for xlsx output.
  - Fixed packaging error on Python 3.
  - Added LaTeX table export format (``Dataset.latex``).
  - Support for dBase (DBF) files (``Dataset.dbf``).
  - New import/export interface (``Dataset.export()``, ``Dataset.load()``).
  - CSV custom delimiter support (``Dataset.export('csv', delimiter='$')``).
  - Adding ability to remove duplicates to all rows in a dataset (``Dataset.remove_duplicates()``).
  - Added a mechanism to avoid ``datetime.datetime`` issues when serializing data.
  - New ``detect_format()`` function (mostly for internal use).
  - Update the vendored unicodecsv to fix ``None`` handling.
  - Only freeze the headers row, not the headers columns (xls).
  - ``detect()`` function removed.
  - Fix XLSX import.
  - Bugfix for ``Dataset.transpose().transpose()``.
- convert to singlespec
* Fri Jul 24 2015 seife+obs@b1-systems.com
- fix RHEL build by ignoring bytecompile-errors
* Thu May 14 2015 benoit.monin@gmx.fr
- update to version 0.10.0:
  * Unicode Column Headers
  * ALL the bugfixes!
- add fdupes as BuildRequires and call it after install
- remove shebang in every python files
- remove useless CFLAGS declaration
- run the tests during build with test_tablib.py
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Fri Jul 27 2012 saschpe@suse.de
- Initial version
